@@ -14,8 +14,10 @@
 
 from substra.sdk.client import Client
 from substra.sdk.utils import retry_on_exception
+from substra.sdk.backends.local.backend import DEBUG_OWNER
 
 __all__ = [
     'Client',
     'retry_on_exception',
+    'DEBUG_OWNER',
 ]
