@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import os
-from pathlib import Path
 import shutil
 import typing
 import warnings
@@ -33,7 +32,7 @@ DEBUG_OWNER = "debug_owner"
 class Local(base.BaseBackend):
     def __init__(self, backend, *args, **kwargs):
         self._support_chainkeys = bool(util.strtobool(os.getenv("CHAINKEYS_ENABLED", 'False')))
-        self._chainkey_dir = Path(os.getenv("CHAINKEYS_DIR", Path.home() / ".substra_chainkeys"))
+        self._chainkey_dir = compute.LOCAL_DIR / "chainkeys"
         if self._support_chainkeys:
             print(f"Chainkeys support is on, the directory is {self._chainkey_dir}")
         # create a store to abstract the db
@@ -949,6 +948,13 @@ class Local(base.BaseBackend):
         else:
             self._db.remote_download(asset_type, url_field_path, key, destination)
 
+    def download_model(self, key, destination_file):
+        if self._db.is_local(key):
+            asset = self._db.get(type_=schemas.Type.Model, key=key)
+            shutil.copyfile(asset.storage_address, destination_file)
+        else:
+            self._db.remote_download_model(key, destination_file)
+
     def describe(self, asset_type, key):
         if self._db.is_local(key):
             asset = self._db.get(type_=asset_type, key=key)
@@ -959,6 +965,9 @@ class Local(base.BaseBackend):
         else:
             return self._db.get_remote_description(asset_type, key)
 
+    def node_info(self):
+        return {"type": "local backend"}
+
     def leaderboard(self, objective_key, sort='desc'):
         objective = self._db.get(schemas.Type.Objective, objective_key)
         testtuples = self._db.list(schemas.Type.Testtuple, filters=None)
