@@ -22,6 +22,8 @@ from substra.sdk import schemas, fs, models
 from substra.sdk.backends.local import dal
 from substra.sdk.backends.local.compute import spawner
 
+LOCAL_DIR = pathlib.Path.cwd() / "local-worker"
+
 _CONTAINER_MODEL_PATH = "/sandbox/model"
 
 _VOLUME_INPUT_DATASAMPLES = {"bind": "/sandbox/data", "mode": "ro"}
@@ -30,7 +32,6 @@ _VOLUME_MODELS_RW = {"bind": _CONTAINER_MODEL_PATH, "mode": "rw"}
 _VOLUME_OPENER = {"bind": "/sandbox/opener/__init__.py", "mode": "ro"}
 _VOLUME_OUTPUT_PRED = {"bind": "/sandbox/pred", "mode": "rw"}
 _VOLUME_LOCAL = {"bind": "/sandbox/local", "mode": "rw"}
-_VOLUME_LOCAL_READ_ONLY = {"bind": "/sandbox/local", "mode": "ro"}
 _VOLUME_CHAINKEYS = {"bind": "/sandbox/chainkeys", "mode": "rw"}
 
 _VOLUME_INPUT_MODELS_RO = {"bind": "/sandbox/input_models", "mode": "ro"}
@@ -55,7 +56,7 @@ class Worker:
     """ML Worker."""
 
     def __init__(self, db: dal.DataAccess, support_chainkeys: bool, chainkey_dir=None):
-        self._wdir = os.path.join(os.getcwd(), "local-worker")
+        self._wdir = LOCAL_DIR
         self._db = db
         self._spawner = spawner.get()
         self._support_chainkeys = support_chainkeys
@@ -105,7 +106,8 @@ class Worker:
         model_dir = _mkdir(os.path.join(self._wdir, "models", tuple_.key))
         model_path = os.path.join(model_dir, model_name)
         shutil.copy(tmp_path, model_path)
-        return models.OutModel(key=str(uuid.uuid4()), checksum=fs.hash_file(model_path),
+        return models.OutModel(key=self._db.get_local_key(str(uuid.uuid4())),
+                               checksum=fs.hash_file(model_path),
                                storage_address=model_path)
 
     def _get_command_models_composite(self, is_train, tuple_, models_volume, container_volume):
@@ -201,9 +203,10 @@ class Worker:
 
             if tuple_.compute_plan_key:
                 #  Shared compute plan volume
+                owner = self._get_owner(tuple_)
                 local_volume = _mkdir(
                     os.path.join(
-                        self._wdir, "compute_plans", "local", tuple_.compute_plan_key
+                        self._wdir, "compute_plans", owner, tuple_.compute_plan_key
                     )
                 )
                 volumes[local_volume] = _VOLUME_LOCAL
@@ -316,9 +319,10 @@ class Worker:
                 volumes[data_volume] = _VOLUME_INPUT_DATASAMPLES
 
             if tuple_.compute_plan_key:
+                owner = self._get_owner(tuple_)
                 local_volume = _mkdir(
                     os.path.join(
-                        self._wdir, "compute_plans", "local", tuple_.compute_plan_key
+                        self._wdir, "compute_plans", owner, tuple_.compute_plan_key
                     )
                 )
                 volumes[local_volume] = _VOLUME_LOCAL
@@ -380,8 +384,13 @@ class Worker:
             }
 
             if self._db.is_local(dataset.key):
+                data_sample_paths = self._get_data_sample_paths_arg(
+                    _VOLUME_INPUT_DATASAMPLES['bind'],
+                    tuple_.dataset
+                )
                 volumes[data_volume] = _VOLUME_INPUT_DATASAMPLES
                 command = "--fake-data-mode DISABLED"
+                command += f" --data-sample-paths {data_sample_paths}"
             else:
                 command = "--fake-data-mode FAKE_Y"
                 command += f" --n-fake-samples {len(tuple_.dataset.data_sample_keys)}"
