@@ -15,7 +15,7 @@
 import collections
 import logging
 
-from substra.sdk import exceptions, models
+from substra.sdk import exceptions
 
 logger = logging.getLogger(__name__)
 
@@ -30,17 +30,10 @@ class InMemoryDb:
     def add(self, asset):
         """Add an asset."""
         type_ = asset.__class__.type_
+        key = asset.key
 
-        if type_ == models.ComputePlan.type_:
-            key = asset.compute_plan_id
-        else:
-            key = asset.key
-
-        if key in self._data[type_]:
-            raise exceptions.AlreadyExists(key, 409)
-        else:
-            self._data[type_][key] = asset
-            logger.info(f"{type_} with key '{key}' has been created.")
+        self._data[type_][key] = asset
+        logger.info(f"{type_} with key '{key}' has been created.")
 
         return asset
 
@@ -59,29 +52,10 @@ class InMemoryDb:
 
     def update(self, asset):
         type_ = asset.__class__.type_
-        if type_ == models.ComputePlan.type_:
-            key = asset.compute_plan_id
-        else:
-            key = asset.key
+        key = asset.key
 
         if key not in self._data[type_]:
             raise exceptions.NotFound(f"Wrong pk {key}", 404)
 
         self._data[type_][key] = asset
         return asset
-
-
-_SHARED_DB = None
-
-
-def reset():
-    global _SHARED_DB
-    _SHARED_DB = InMemoryDb()
-    return _SHARED_DB
-
-
-def get():
-    global _SHARED_DB
-    if not _SHARED_DB:
-        reset()
-    return _SHARED_DB
