@@ -630,7 +630,7 @@ class Client(object):
             models.ComputePlan: updated compute plan, as described in the
             [models.ComputePlan](sdk_models.md#ComputePlan) model
         """
-        spec = schemas.UpdateComputePlanSpec(**data)
+        spec = self._get_spec(schemas.UpdateComputePlanSpec, data)
         spec_options = {
             "auto_batching": auto_batching,
             "batch_size": batch_size,
@@ -721,6 +721,80 @@ class Client(object):
             os.path.join(destination_folder, 'metrics.py'),
         )
 
+    @logit
+    def download_model(self, key: str, folder) -> None:
+        """Download model to destination file.
+
+        This model was saved using the 'save_model' function of the algorithm.
+        To load and use the model, please refer to the 'load_model' and 'predict' functions of the
+        algorithm.
+        """
+        self._backend.download_model(key, os.path.join(folder, f'model_{key}'))
+
+    @logit
+    def download_model_from_traintuple(self, tuple_key: str, folder) -> None:
+        """Download traintuple model to destination file.
+
+        This model was saved using the 'save_model' function of the algorithm.
+        To load and use the model, please refer to the 'load_model' and 'predict' functions of the
+        algorithm.
+        """
+        self._download_model_from_tuple(schemas.Type.Traintuple, tuple_key, folder)
+
+    @logit
+    def download_model_from_aggregatetuple(self, tuple_key: str, folder) -> None:
+        """Download aggregatetuple model to destination file.
+
+        This model was saved using the 'save_model' function of the algorithm.
+        To load and use the model, please refer to the 'load_model' and 'predict' functions of the
+        algorithm.
+        """
+        self._download_model_from_tuple(schemas.Type.Aggregatetuple, tuple_key, folder)
+
+    @logit
+    def download_head_model_from_composite_traintuple(self, tuple_key: str, folder) -> None:
+        """Download composite traintuple head model to destination file.
+
+        This model was saved using the 'save_model' function of the algorithm.
+        To load and use the model, please refer to the 'load_model' and 'predict' functions of the
+        algorithm.
+        """
+        self._download_model_from_tuple(schemas.Type.CompositeTraintuple, tuple_key, folder, "head")
+
+    @logit
+    def download_trunk_model_from_composite_traintuple(self, tuple_key: str, folder) -> None:
+        """Download composite traintuple trunk model to destination file.
+
+        This model was saved using the 'save_model' function of the algorithm.
+        To load and use the model, please refer to the 'load_model' and 'predict' functions of the
+        algorithm.
+        """
+        self._download_model_from_tuple(schemas.Type.CompositeTraintuple, tuple_key, folder,
+                                        "trunk")
+
+    def _download_model_from_tuple(self, tuple_type, tuple_key, folder, head_trunk=None) -> None:
+        """Download model to a destination file."""
+        tuple = self._backend.get(tuple_type, tuple_key)
+
+        if tuple_type == schemas.Type.CompositeTraintuple:
+            if head_trunk == "head":
+                model = tuple.out_head_model.out_model
+            elif head_trunk == "trunk":
+                model = tuple.out_trunk_model.out_model
+            else:
+                raise exceptions.InvalidRequest(
+                    'head_trunk parameter must have value "head" or "trunk"'
+                )
+        else:
+            model = tuple.out_model
+
+        if not model:
+            desc = f'{head_trunk} ' if head_trunk else ""
+            msg = f'{tuple_type} {tuple_key}, status "{tuple.status}" has no {desc}out-model'
+            raise exceptions.NotFound(msg, 404)
+
+        self.download_model(model.key, folder)
+
     @logit
     def describe_algo(self, key: str) -> str:
         """Get algo description."""
@@ -746,6 +820,11 @@ class Client(object):
         """Get objective description."""
         return self._backend.describe(schemas.Type.Objective, key)
 
+    @logit
+    def node_info(self) -> str:
+        """Get node information."""
+        return self._backend.node_info()
+
     @logit
     def leaderboard(self, objective_key: str, sort: str = 'desc') -> str:
         """Get objective leaderboard"""
